"""Example decorator implementation for Nuke."""

# Import built-in modules
import hashlib

# Import third-party modules
import nuke  # pylint: disable=import-error

# Md5 sum of password for executing our secret functions ('secret123').
_PW = "5d7845ac6ee7cfffafc5fe5f35cf666d"


def password_required(function):
    """Ask user for password prior to executing given function.

    Args:
        function (function): Function to execute when the entered password is
            entered correctly.

    """

    def wrapper(*args):
        """Wrap getting password from user before executing function.

        Args:
            multiple: Arguments to pass into the given function.

        """
        panel = nuke.Panel("Password required")
        panel.addPasswordInput('password', '')

        if panel.show():
            user_secret = hashlib.md5(panel.value("password")).hexdigest()
            if user_secret != _PW:
                nuke.message("Wrong password")
                return

            function(*args)

    return wrapper



@password_required
def create_secret_blur():
    """Secret dummy function 1."""
    for _ in range(10):
        nuke.createNode("Blur")


@password_required
def create_secret_roto():
    """Secret dummy function 2."""
    for _ in range(10):
        nuke.createNode("Roto")
